<?php namespace WeCodeArt\Customizer;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit(); 

/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Customizer/Controls
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		v3.5
 * @version		v3.6.2
 */

class Controls {
	use \WeCodeArt\Singleton;  

	/**
	 * Registered Controls.
	 *
	 * @since 	3.5
	 * @var 	Array
	 */
	public static $controls; 
	
	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {
		// Register our custom controls.
		add_action( 'customize_register', [ $this, 'register_controls' ] );
	}

	/**
	 * Register Customizer Controls
	 */
	public function register_controls( $wp_customize ) { 
		if( ! self::$controls ) return;
		foreach( self::$controls as $name => $atts ) {
			if ( isset( $atts['callback'] ) ) $wp_customize->register_control_type( $atts['callback'] ); 
		}
	}

	/**
	 * Add Control to self::$controls and Register control to WordPress Customizer.
	 *
	 * @param 	String $name Slug for the control.
	 * @param 	Array  $atts Control Attributes.
	 * @return 	void
	 */
	public static function add_control( $name, $atts ) {
		self::$controls[ $name ] = $atts;
	}

	/**
	 * Returns control instance
	 * @param  	string 	$control_type control type.
	 * @since 	3.5
	 * @return 	string
	 */
	public static function get_control_instance( $control_type ) {
		$control_class = self::get_control( $control_type );
		if ( isset( $control_class['callback'] ) ) {
			return class_exists( $control_class['callback'] ) ? $control_class['callback'] : false;
		}
		return false;
	}

	/**
	 * Returns control and its attributes
	 * @param  	string 	$control_type control type.
	 * @since 	3.5
	 * @return 	array
	 */
	public static function get_control( $control_type ) {
		if ( isset( self::$controls[ $control_type ] ) ) return self::$controls[ $control_type ]; 
		return array();
	}

	/**
	 * Returns Santize callback for control
	 * @param  	string 	$control control.
	 * @since 	3.5
	 * @return 	string
	 */
	public static function get_sanitize_call( $control ) {
		if ( isset( self::$controls[ $control ]['sanitize_callback'] ) ) {
			return self::$controls[ $control ]['sanitize_callback'];
		}
		return false;
	}
} 

/**
 * Register Custom Customizer Controls
 */
Controls::add_control( 'wecodeart-slider', [ 
	'callback' 			=> 'WeCodeArt\Customizer\Controls\Slider',
	'sanitize_callback' => ['WeCodeArt\Customizer\Formatting', 'sanitize_number']
] );
Controls::add_control( 'wecodeart-sortable', [ 
	'callback' 			=> 'WeCodeArt\Customizer\Controls\Sortable',
	'sanitize_callback' => ['WeCodeArt\Customizer\Formatting', 'sanitize_sortable_choices']
] ); 