<?php namespace WeCodeArt;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit();
// Use
use WeCodeArt\Support\WooCommerce;
use WeCodeArt\Support\WordPressSeo;
use WeCodeArt\Utilities\Helpers;
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage  Theme Support
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		v3.5
 * @version		v3.6.2
 */

class Support {
	use \WeCodeArt\Singleton; 

	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {

		// Theme Support
		add_action( 'after_setup_theme', [ $this, 'after_setup_theme' ], 2 );

		// Integrations/Compatability/Plugin Support
		if( Helpers::detectplugin( [ 'classes' 		=> [ 'woocommerce' ] ] ) )		WooCommerce::get_instance();
		if( Helpers::detectplugin( [ 'constants' 	=> [ 'WPSEO_VERSION' ] ] ) ) 	WordPressSeo::get_instance();
	}

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function after_setup_theme() {
		/**
		 * Get post types for Config Options
		 * @uses apply_filters for changing this query args
		 */
		$get_post_types = get_post_types( 
			apply_filters( 'wecodeart/support/get_post_types_args', [ 
				'public' => true, 
				'publicly_queryable' => true 
			] )
		); 

		// Content width
		$GLOBALS['content_width'] = apply_filters( 'wecodeart/filter/content_width', 1280 );

		// Translation
		load_theme_textdomain( 'wecodeart', get_template_directory_uri() . '/languages' );	

		// Automatic Feed Links
		add_theme_support( 'automatic-feed-links' );

		// Title Tag
		add_theme_support( 'title-tag' );

		// Selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Thumbnails
		add_theme_support( 'post-thumbnails' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Editor Style
		add_theme_support( 'editor-style' );

		// Custom Logo
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 100,
		) );

		/**
		 * Add support for responsive embedded content.
		 */
		add_theme_support( 'responsive-embeds' );

		// Add support for Meta info for posts other than Page Type 
		foreach( $get_post_types as $type ) add_post_type_support( $type, 'wecodeart-post-info' ); 

		// Register New Menu
		register_nav_menus( array(
			'primary' => __( 'Primary Menu', 'wecodeart' ),
		) );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => __( 'Small', 'wecodeart' ),
					'shortName' => __( 'S', 'wecodeart' ),
					'size'      => 14,
					'slug'      => 'small',
				),
				array(
					'name'      => __( 'Normal', 'wecodeart' ),
					'shortName' => __( 'M', 'wecodeart' ),
					'size'      => 16,
					'slug'      => 'normal',
				),

				array(
					'name'      => __( 'Large', 'wecodeart' ),
					'shortName' => __( 'L', 'wecodeart' ),
					'size'      => 26,
					'slug'      => 'large',
				),
				array(
					'name'      => __( 'Huge', 'wecodeart' ),
					'shortName' => __( 'XL', 'wecodeart' ),
					'size'      => 49.5,
					'slug'      => 'huge',
				),
			)
		);

		// Editor color palette.
		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => __( 'Primary', 'wecodeart' ),
					'slug'  => 'primary',
					'color' => '#0088cc',
				),
				array(
					'name'  => __( 'Secondary', 'wecodeart' ),
					'slug'  => 'secondary',
					'color' => '#0066cc',
				),
				array(
					'name'  => __( 'Dark Gray', 'wecodeart' ),
					'slug'  => 'dark-gray',
					'color' => '#111',
				),
				array(
					'name'  => __( 'Light Gray', 'wecodeart' ),
					'slug'  => 'light-gray',
					'color' => '#f1f3f7',
				),
				array(
					'name'  => __( 'White', 'wecodeart' ),
					'slug'  => 'white',
					'color' => '#FFF',
				),
			)
		);
	}
}